[![Downloads](https://pypip.in/download/django-allauth-intersis/badge.svg)](https://pypi.python.org/pypi/django-allauth-intersis/)
django-allauth-intersis
=============
OAuth2.0 InterSIS access module for projects using django-allauth.

This module allows users of django-allauth to seamlessly integrate InterSIS single sign-on into their Django projects.
InterSIS is an in-development, open student-information and single sign-on API spec and implementation.

This module will not be suitable for general use until the first official release of the InterSIS API implementation.


Installation
===============

Install the module in your Python distribution or virtualenv:

    $ pip install django-allauth-intersis

Add the application to your `INSTALLED_APPS`:

```
  INSTALLED_APPS = (
  ...
  'allauth_intersis',
  ...
  )
```

In settings.py:

```
    ...
    INTERSIS_CLIENT_NAME='Example Your Client/Application Name'
    BASE_INTERSIS_SERVER_URL='https://intersis.example.edu'
    BASE_INTERSIS_CLIENT_URL='https://example.your_domain.com'
    ...
```

And in urls.py:

```
    ...
    url(r'^intersis/', include('allauth_intersis.urls')),  # Must come AFTER your allauth.urls line
    ...

```

Of course, you must also have django-allauth installed. See the django-allauth project homepage for description and instructions:
  http://www.intenct.nl/projects/django-allauth/


Use
===

Detailed use instructions to follow, upon the first official release of the InterSIS API implementation.


Compatibility
=============

* Django 1.7
* Python 2.7, 3.4
* Allauth 0.19.0

Todo
====

* Multiple features privately tracked

Getting Involved
================

If you are interested in following the InterSIS project, please contact me (JASchilz) at my listed email address.

